server_client_20141231_085104

### config1 : test_fault_tolerance

Result | Function execution time | Total execution time
--- | --- | ---
Failed | Finished with error | 4.71791219711 sec

Error message: Server did not pass fault tolerance
Other messages: Traceback (most recent call last): File "/Users/jehrlich/workspace/venv/lib/python2.7/site-packages/zopkio-0.1.8-py2.7.egg/zopkio/test_runner.py", line 323, in _execute_single_test test.function() File "/Users/jehrlich/workspace/zopkio/examples/server_client/test_suites/multi_server_tests.py", line 63, in test_fault_tolerance client_deployer.start("client1", configs={"args": "localhost 8000".split() + SMALL_SAMPLE, "sync": True}) File "/Users/jehrlich/workspace/venv/lib/python2.7/site-packages/zopkio-0.1.8-py2.7.egg/zopkio/adhoc_deployer.py", line 183, in start chan = better_exec_command(ssh, command, "Failed to start") File "/Users/jehrlich/workspace/venv/lib/python2.7/site-packages/zopkio-0.1.8-py2.7.egg/zopkio/remote_host_helper.py", line 97, in better_exec_command raise ParamikoError(msg, err_msg) ParamikoError: Failed to start Exception in thread "main" java.util.EmptyStackException at java.util.Stack.peek(Stack.java:102) at org.apache.logging.log4j.core.impl.ThrowableProxy.resolvePackageData(ThrowableProxy.java:339) at org.apache.logging.log4j.core.impl.ThrowableProxy.(ThrowableProxy.java:71) at org.apache.logging.log4j.core.impl.Log4jLogEvent.(Log4jLogEvent.java:108) at org.apache.logging.log4j.core.impl.Log4jLogEvent.(Log4jLogEvent.java:79) at org.apache.logging.log4j.core.config.LoggerConfig.createEvent(LoggerConfig.java:352) at org.apache.logging.log4j.core.config.LoggerConfig.log(LoggerConfig.java:280) at org.apache.logging.log4j.core.Logger.log(Logger.java:108) at org.apache.logging.log4j.spi.AbstractLogger.error(AbstractLogger.java:1075) at AdditionClient.main(AdditionClient.java:68)

Naarad report

### Metrics

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | qps | mean lt 7.0 | None
server1-perf | latency | p50 lt 0.3 | None
server1-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
client1-perf | qps | mean lt 2.0 | None
client1-perf | latency | p50 lt 22.0 | None
client1-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None